#define COMPILE_DL_LDAP 1
#define HAVE_3ARG_SETREBINDPROC 1
#define HAVE_DLFCN_H 1
#define HAVE_LDAP 1
#define HAVE_LDAP_CONTROL_FIND 1
#define HAVE_LDAP_EXTENDED_OPERATION 1
#define HAVE_LDAP_EXTENDED_OPERATION_S 1
#define HAVE_LDAP_PARSE_EXTENDED_RESULT 1
#define HAVE_LDAP_PARSE_REFERENCE 1
#define HAVE_LDAP_PARSE_RESULT 1
#define HAVE_LDAP_PASSWD 1
#define HAVE_LDAP_REFRESH_S 1
#define HAVE_LDAP_SASL 1
#define HAVE_LDAP_START_TLS_S 1
#define HAVE_LDAP_WHOAMI_S 1
